import { useEffect } from 'react'
import { useQuery, keepPreviousData } from '@tanstack/react-query'
import { getUser, getMapList, getMyList, getMyField } from '@/api/base'
import { useUserStore } from '@/stores/user'
import { useMapStore } from '@/stores/map'

export function useUserQuery() {
  const { setUser } = useUserStore()

  const query = useQuery({ queryKey: ['user'], queryFn: getUser, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setUser(query.data)
    }
  }, [query.data, setUser])

  return query
}

export function useMapQuery() {
  const { setMap } = useMapStore()

  const query = useQuery({ queryKey: ['dictionary'], queryFn: getMapList, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setMap(query.data)
    }
  }, [query.data, setMap])

  return query
}

// 我的数据集
export function useDataQuery(params?: Partial<{ page: number; 'per-page': number }>) {
  const query = useQuery({
    queryKey: ['data', params],
    queryFn: () => {
      return getMyList(params)
    },
    select: (res) => res.data,
    initialData: (): any => {
      return { data: { total: 0, list: [], title: [] } }
    },
    placeholderData: keepPreviousData,
  })

  return query
}

// 查看字段详情
export function useDataFieldQuery() {
  const query = useQuery({ queryKey: ['data-filed'], queryFn: getMyField, select: (res) => res.data })

  return query
}
