import { useState } from 'react'
import { Button, Radio, Divider, Flex, Modal, Steps } from 'antd'
import type { RadioChangeEvent } from 'antd'
import { useNavigate } from 'react-router'

const plainOptions = ['会员情况', '客户满意度', '出生日期', '访问页面时长', '交易状态', '商品状态', '快递反馈']

export default function ButtonModal() {
  const navigate = useNavigate()
  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)

  const [value, setValue] = useState(1)

  const onChange = (e: RadioChangeEvent) => {
    setValue(e.target.value)
  }
  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const steps = [
    {
      title: '探索过小值字段',
    },
    {
      title: '处理过小值',
    },
  ]

  const style: React.CSSProperties = {
    display: 'flex',
    flexDirection: 'column',
    gap: 8,
  }
  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        过小值
      </Button>
      <Modal
        title="过小值探索"
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && <Button type="primary">智能探索过小值字段</Button>}

            {current > 0 && (
              <Button style={{ margin: '0 8px' }} onClick={() => prev()}>
                上一步
              </Button>
            )}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => navigate('/data/preprocess/min')}>
                跳转数据预处理
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '40px 0' }}>
          <Steps current={current} labelPlacement="vertical" items={steps} />
          <Divider />
          <Flex justify="space-between">探索结果：</Flex>
          <Divider dashed />
          <Radio.Group options={plainOptions} value={value} onChange={onChange} style={style} />
        </div>
      </Modal>
    </>
  )
}
